@@ -14,6 +14,7 @@
 #include <QMimeDatabase>
 #include <QMessageBox>
 #include <QToolBar>
+#include <QActionGroup>
 #include <QCompleter>
 #include <QShortcut>
 #include <QTimer>
@@ -95,7 +96,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     connect(ui->fileTypeCombo, &QComboBox::currentTextChanged, [this](const QString& text) {
         selectNameFilter(text);
     });
-    ui->fileTypeCombo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLength);
+    ui->fileTypeCombo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
     ui->fileTypeCombo->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     ui->fileTypeCombo->setCurrentIndex(0);
 
@@ -140,7 +141,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
     toolbar->addSeparator();
 
     // a shortcut for deselecting all items
-    QShortcut* shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_D), this);
+    QShortcut* shortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_D), this);
     connect(shortcut, &QShortcut::activated, [this]() {
         ui->folderView->selectionModel()->clearSelection();
     });
@@ -209,7 +210,7 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
         proxyModel_->setShowHidden(checked);
     });
     // also add a separate shortcut for it
-    shortcut = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_H), this);
+    shortcut = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_H), this);
     connect(shortcut, &QShortcut::activated, [this]() {
         proxyModel_->setShowHidden(!proxyModel_->showHidden());
     });
@@ -542,7 +543,7 @@ QString FileDialog::suffix(bool checkDefaultSuffix) const {
                 left = suffix.indexOf(QLatin1Char('.')); // it can be like ".tar.xz"
                 if(left != -1 && suffix.size() - left > 1) {
                     suffix = suffix.right(suffix.size() - left - 1);
-                    if(suffix.indexOf(QRegularExpression(QStringLiteral("\\W"))) == -1) {
+                    if(suffix.indexOf(QRegularExpression(QStringLiteral("[^\\w\\.]"))) == -1) {
                         return suffix;
                     }
                 }
@@ -1111,10 +1112,6 @@ void FileDialog::setViewMode(FolderView::ViewMode mode) {
 
 
 void FileDialog::setFileMode(QFileDialog::FileMode mode) {
-    if(mode == QFileDialog::DirectoryOnly) {
-        // directly only is deprecated and not allowed.
-        mode = QFileDialog::Directory;
-    }
     fileMode_ = mode;
 
     // enable multiple selection?
