@@ -478,155 +478,155 @@ What do you want to do with it?</source>
 <context>
     <name>Fm::FileDialog</name>
     <message>
-        <location filename="../filedialog.cpp" line="105"/>
+        <location filename="../filedialog.cpp" line="106"/>
         <source>Go Back</source>
         <translation>Назад</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="106"/>
+        <location filename="../filedialog.cpp" line="107"/>
         <source>Alt+Left</source>
         <comment>Go Back</comment>
         <translation>Alt+Вліво</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="112"/>
+        <location filename="../filedialog.cpp" line="113"/>
         <source>Go Forward</source>
         <translation>Вперед</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="113"/>
+        <location filename="../filedialog.cpp" line="114"/>
         <source>Alt+Right</source>
         <comment>Go Forward</comment>
         <translation>Alt+Вправо</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="120"/>
+        <location filename="../filedialog.cpp" line="121"/>
         <source>Reload</source>
         <translation>Оновити</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="121"/>
+        <location filename="../filedialog.cpp" line="122"/>
         <source>F5</source>
         <comment>Reload</comment>
         <translation>F5</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="138"/>
+        <location filename="../filedialog.cpp" line="139"/>
         <source>Create Folder</source>
         <translation>Створити теку</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="154"/>
+        <location filename="../filedialog.cpp" line="155"/>
         <source>Icon View</source>
         <translation>У вигляді піктограм</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="158"/>
+        <location filename="../filedialog.cpp" line="159"/>
         <source>Thumbnail View</source>
         <translation>У вигляді ескізів</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="162"/>
+        <location filename="../filedialog.cpp" line="163"/>
         <source>Compact View</source>
         <translation>Компактний вигляд</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="166"/>
+        <location filename="../filedialog.cpp" line="167"/>
         <source>Detailed List View</source>
         <translation>Подання детальним переліком</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="174"/>
+        <location filename="../filedialog.cpp" line="175"/>
         <source>Icon Sizes</source>
         <translation>Розміри піктограм</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="176"/>
+        <location filename="../filedialog.cpp" line="177"/>
         <source>Size of big icons:</source>
         <translation>Розмір великих піктограм:</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="183"/>
+        <location filename="../filedialog.cpp" line="184"/>
         <source>Size of small icons:</source>
         <translation>Розмір маленьких піктограм:</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="190"/>
+        <location filename="../filedialog.cpp" line="191"/>
         <source>Size of thumbnails:</source>
         <translation>Розмір ескізів:</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="206"/>
+        <location filename="../filedialog.cpp" line="207"/>
         <source>Show Hidden</source>
         <translation>Показати сховані</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="218"/>
+        <location filename="../filedialog.cpp" line="219"/>
         <source>Show Thumbnails</source>
         <translation>Показувати ескізи</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="223"/>
+        <location filename="../filedialog.cpp" line="224"/>
         <source>Show File Tooltips</source>
         <translation>Показувати підказки для файлів</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="230"/>
+        <location filename="../filedialog.cpp" line="231"/>
         <source>Smooth Scrolling</source>
         <translation>Плавне прокручування</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="245"/>
+        <location filename="../filedialog.cpp" line="246"/>
         <source>Options</source>
         <translation>Параметри</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="595"/>
-        <location filename="../filedialog.cpp" line="990"/>
+        <location filename="../filedialog.cpp" line="596"/>
+        <location filename="../filedialog.cpp" line="991"/>
         <source>Error</source>
         <translation>Помилка</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="595"/>
+        <location filename="../filedialog.cpp" line="596"/>
         <source>Please select a file</source>
         <translation>Виберіть файл</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="637"/>
+        <location filename="../filedialog.cpp" line="638"/>
         <source>%1 already exists.
 Do you want to replace it?</source>
         <translation>%1 вже існує.
 Бажаєте замінити його?</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="960"/>
+        <location filename="../filedialog.cpp" line="961"/>
         <source>Path &quot;%1&quot; does not exist</source>
         <translation>Шляху «%1» не існує</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="974"/>
+        <location filename="../filedialog.cpp" line="975"/>
         <source>&quot;%1&quot; is not a directory</source>
         <translation>«%1» не є текою</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="980"/>
+        <location filename="../filedialog.cpp" line="981"/>
         <source>&quot;%1&quot; is not a file</source>
         <translation>«%1» не є файлом</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="1132"/>
-        <location filename="../filedialog.cpp" line="1240"/>
+        <location filename="../filedialog.cpp" line="1129"/>
+        <location filename="../filedialog.cpp" line="1237"/>
         <source>&amp;Open</source>
         <translation>&amp;Відкрити</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="1135"/>
-        <location filename="../filedialog.cpp" line="1248"/>
+        <location filename="../filedialog.cpp" line="1132"/>
+        <location filename="../filedialog.cpp" line="1245"/>
         <source>&amp;Save</source>
         <translation>&amp;Зберегти</translation>
     </message>
     <message>
-        <location filename="../filedialog.cpp" line="1142"/>
+        <location filename="../filedialog.cpp" line="1139"/>
         <source>All Files (*)</source>
         <translation>Усі файли (*)</translation>
     </message>
@@ -993,17 +993,17 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FileSearchDialog</name>
     <message>
-        <location filename="../filesearchdialog.cpp" line="152"/>
+        <location filename="../filesearchdialog.cpp" line="157"/>
         <source>Error</source>
         <translation>Помилка</translation>
     </message>
     <message>
-        <location filename="../filesearchdialog.cpp" line="152"/>
+        <location filename="../filesearchdialog.cpp" line="157"/>
         <source>You should add at least one directory to search.</source>
         <translation>Ви повинні додати хоча б одну теку для пошуку.</translation>
     </message>
     <message>
-        <location filename="../filesearchdialog.cpp" line="159"/>
+        <location filename="../filesearchdialog.cpp" line="164"/>
         <source>Select a folder</source>
         <translation>Вибір теки</translation>
     </message>
@@ -1024,112 +1024,112 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FolderMenu</name>
     <message>
-        <location filename="../foldermenu.cpp" line="57"/>
+        <location filename="../foldermenu.cpp" line="58"/>
         <source>Empty Trash</source>
         <translation>Спорожнити смітник</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="69"/>
+        <location filename="../foldermenu.cpp" line="70"/>
         <source>Create &amp;New</source>
         <translation>Створити &amp;новий</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="74"/>
+        <location filename="../foldermenu.cpp" line="75"/>
         <source>&amp;Paste</source>
         <translation>&amp;Вставити</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="87"/>
+        <location filename="../foldermenu.cpp" line="88"/>
         <source>Select &amp;All</source>
         <translation>Вибрати в&amp;се</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="91"/>
+        <location filename="../foldermenu.cpp" line="92"/>
         <source>Invert Selection</source>
         <translation>Обернути вибране</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="98"/>
+        <location filename="../foldermenu.cpp" line="99"/>
         <source>Sorting</source>
         <translation>Сортування</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="103"/>
+        <location filename="../foldermenu.cpp" line="104"/>
         <source>Show Hidden</source>
         <translation>Показати приховане</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="138"/>
+        <location filename="../foldermenu.cpp" line="139"/>
         <source>Folder Pr&amp;operties</source>
         <translation>Властив&amp;ості теки</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="181"/>
+        <location filename="../foldermenu.cpp" line="182"/>
         <source>Output</source>
         <translation>Вивід</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="203"/>
+        <location filename="../foldermenu.cpp" line="204"/>
         <source>By File Name</source>
         <translation>За назвою файлу</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="204"/>
+        <location filename="../foldermenu.cpp" line="205"/>
         <source>By Modification Time</source>
         <translation>За датою зміни</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="205"/>
+        <location filename="../foldermenu.cpp" line="206"/>
         <source>By Creation Time</source>
         <translation>За часом створення</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="208"/>
+        <location filename="../foldermenu.cpp" line="209"/>
         <source>By Deletion Time</source>
         <translation>За часом видалення</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="211"/>
+        <location filename="../foldermenu.cpp" line="212"/>
         <source>By File Size</source>
         <translation>За розміром файлу</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="212"/>
+        <location filename="../foldermenu.cpp" line="213"/>
         <source>By File Type</source>
         <translation>За типом файлу</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="213"/>
+        <location filename="../foldermenu.cpp" line="214"/>
         <source>By File Owner</source>
         <translation>За власником файлу</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="214"/>
+        <location filename="../foldermenu.cpp" line="215"/>
         <source>By File Group</source>
         <translation>За групою файлу</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="220"/>
+        <location filename="../foldermenu.cpp" line="221"/>
         <source>Ascending</source>
         <translation>За зростанням</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="225"/>
+        <location filename="../foldermenu.cpp" line="226"/>
         <source>Descending</source>
         <translation>За спаданням</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="242"/>
+        <location filename="../foldermenu.cpp" line="243"/>
         <source>Folder First</source>
         <translation>Спочатку теки</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="250"/>
+        <location filename="../foldermenu.cpp" line="251"/>
         <source>Hidden Last</source>
         <translation>Приховані в кінці</translation>
     </message>
     <message>
-        <location filename="../foldermenu.cpp" line="258"/>
+        <location filename="../foldermenu.cpp" line="259"/>
         <source>Case Sensitive</source>
         <translation>Чутливі до регістру</translation>
     </message>
@@ -1137,87 +1137,87 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FolderModel</name>
     <message>
-        <location filename="../foldermodel.cpp" line="307"/>
+        <location filename="../foldermodel.cpp" line="306"/>
         <source>Location:</source>
         <translation>Розташування:</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="311"/>
+        <location filename="../foldermodel.cpp" line="310"/>
         <source>File type:</source>
         <translation>Тип файлу:</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="316"/>
+        <location filename="../foldermodel.cpp" line="315"/>
         <source>File size:</source>
         <translation>Розмір файлу:</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="320"/>
+        <location filename="../foldermodel.cpp" line="319"/>
         <source>Last modified:</source>
         <translation>Востаннє змінено:</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="321"/>
+        <location filename="../foldermodel.cpp" line="320"/>
         <source>Last accessed:</source>
         <translation>Останній доступ:</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="322"/>
+        <location filename="../foldermodel.cpp" line="321"/>
         <source>N/A</source>
         <translation>Недоступно</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="324"/>
+        <location filename="../foldermodel.cpp" line="323"/>
         <source>Created:</source>
         <translation>Створено:</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="329"/>
+        <location filename="../foldermodel.cpp" line="328"/>
         <source>Owner:</source>
         <translation>Власник:</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="330"/>
+        <location filename="../foldermodel.cpp" line="329"/>
         <source>Group:</source>
         <translation>Група:</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="397"/>
+        <location filename="../foldermodel.cpp" line="396"/>
         <source>Name</source>
         <translation>Назва</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="400"/>
+        <location filename="../foldermodel.cpp" line="399"/>
         <source>Type</source>
         <translation>Тип</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="403"/>
+        <location filename="../foldermodel.cpp" line="402"/>
         <source>Size</source>
         <translation>Розмір</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="406"/>
+        <location filename="../foldermodel.cpp" line="405"/>
         <source>Modified</source>
         <translation>Змінено</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="409"/>
+        <location filename="../foldermodel.cpp" line="408"/>
         <source>Created</source>
         <translation>Створено</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="412"/>
+        <location filename="../foldermodel.cpp" line="411"/>
         <source>Deleted</source>
         <translation>Видалено</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="415"/>
+        <location filename="../foldermodel.cpp" line="414"/>
         <source>Owner</source>
         <translation>Власник</translation>
     </message>
     <message>
-        <location filename="../foldermodel.cpp" line="418"/>
+        <location filename="../foldermodel.cpp" line="417"/>
         <source>Group</source>
         <translation>Група</translation>
     </message>
@@ -1225,12 +1225,12 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::FolderViewTreeView</name>
     <message>
-        <location filename="../folderview.cpp" line="406"/>
+        <location filename="../folderview.cpp" line="409"/>
         <source>Auto-resize columns</source>
         <translation>Автозміна ширини стовпців</translation>
     </message>
     <message>
-        <location filename="../folderview.cpp" line="423"/>
+        <location filename="../folderview.cpp" line="426"/>
         <source>Visible Columns</source>
         <translation>Видимі стовпці</translation>
     </message>
@@ -1251,7 +1251,7 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::MountOperationPasswordDialog</name>
     <message>
-        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
+        <location filename="../mountoperationpassworddialog.cpp" line="42"/>
         <source>&amp;Connect</source>
         <translation>&amp;З&apos;єднання</translation>
     </message>
@@ -1259,12 +1259,12 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::PathBar</name>
     <message>
-        <location filename="../pathbar.cpp" line="134"/>
+        <location filename="../pathbar.cpp" line="122"/>
         <source>&amp;Edit Path</source>
         <translation>&amp;Шлях редагування</translation>
     </message>
     <message>
-        <location filename="../pathbar.cpp" line="137"/>
+        <location filename="../pathbar.cpp" line="125"/>
         <source>&amp;Copy Path</source>
         <translation>&amp;Шлях копіювання</translation>
     </message>
@@ -1315,64 +1315,64 @@ Do you want to delete them instead?</source>
 <context>
     <name>Fm::PlacesView</name>
     <message>
-        <location filename="../placesview.cpp" line="542"/>
+        <location filename="../placesview.cpp" line="555"/>
         <source>Open in New Tab</source>
         <translation>Відкрити в новій вкладці</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="545"/>
+        <location filename="../placesview.cpp" line="558"/>
         <source>Open in New Window</source>
         <translation>Відкрити в новому вікні</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="557"/>
+        <location filename="../placesview.cpp" line="570"/>
         <source>Empty Trash</source>
         <translation>Спорожнити смітник</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="577"/>
-        <location filename="../placesview.cpp" line="639"/>
+        <location filename="../placesview.cpp" line="590"/>
+        <location filename="../placesview.cpp" line="652"/>
         <source>Hide</source>
         <translation>Приховати</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="594"/>
+        <location filename="../placesview.cpp" line="607"/>
         <source>Move Bookmark Up</source>
         <translation>Перенести закладку вгору</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="601"/>
+        <location filename="../placesview.cpp" line="614"/>
         <source>Move Bookmark Down</source>
         <translation>Перенести закладку вниз</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="606"/>
+        <location filename="../placesview.cpp" line="619"/>
         <source>Rename Bookmark</source>
         <translation>Перейменувати закладку</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="610"/>
+        <location filename="../placesview.cpp" line="623"/>
         <source>Remove Bookmark</source>
         <translation>Вилучити закладку</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="620"/>
-        <location filename="../placesview.cpp" line="653"/>
+        <location filename="../placesview.cpp" line="633"/>
+        <location filename="../placesview.cpp" line="666"/>
         <source>Unmount</source>
         <translation>Відмонтувати</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="624"/>
+        <location filename="../placesview.cpp" line="637"/>
         <source>Mount</source>
         <translation>Змонтувати</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="630"/>
+        <location filename="../placesview.cpp" line="643"/>
         <source>Eject</source>
         <translation>Витягнути</translation>
     </message>
     <message>
-        <location filename="../placesview.cpp" line="665"/>
+        <location filename="../placesview.cpp" line="678"/>
         <source>Show All Entries</source>
         <translation>Показати всі записи</translation>
     </message>
@@ -1398,17 +1398,17 @@ Modified: %2</source>
 Змінено: %2</translation>
     </message>
     <message>
-        <location filename="../renamedialog.cpp" line="96"/>
+        <location filename="../renamedialog.cpp" line="97"/>
         <source>&amp;Overwrite</source>
         <translation>Пе&amp;резаписати</translation>
     </message>
     <message>
-        <location filename="../renamedialog.cpp" line="98"/>
+        <location filename="../renamedialog.cpp" line="99"/>
         <source>&amp;Rename</source>
         <translation>Пер&amp;ейменувати</translation>
     </message>
     <message>
-        <location filename="../renamedialog.cpp" line="108"/>
+        <location filename="../renamedialog.cpp" line="109"/>
         <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;Файл не може перезаписати сам себе.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Оберіть іншу назву.&lt;/p&gt;</translation>
     </message>
@@ -1473,11 +1473,16 @@ Modified: %2</source>
     </message>
     <message>
         <location filename="../mount-operation-password.ui" line="137"/>
+        <source>Session length is determined by password manager</source>
+        <translation>Тривалість сеансу визначається менеджером паролів</translation>
+    </message>
+    <message>
+        <location filename="../mount-operation-password.ui" line="140"/>
         <source>Remember password for &amp;this session</source>
         <translation>Запам&apos;ятати пароль для &amp;цього сеансу</translation>
     </message>
     <message>
-        <location filename="../mount-operation-password.ui" line="147"/>
+        <location filename="../mount-operation-password.ui" line="150"/>
         <source>Remember &amp;forever</source>
         <translation>Запам&apos;ятати назав&amp;жди</translation>
     </message>
@@ -1485,12 +1490,12 @@ Modified: %2</source>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../utilities.cpp" line="166"/>
+        <location filename="../utilities.cpp" line="170"/>
         <source>Rename File</source>
         <translation>Перейменувати файл</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="167"/>
+        <location filename="../utilities.cpp" line="171"/>
         <source>Please enter a new name:</source>
         <translation>Будь ласка, введіть нову назву:</translation>
     </message>
@@ -1498,43 +1503,43 @@ Modified: %2</source>
         <location filename="../filelauncher.cpp" line="124"/>
         <location filename="../filepropsdialog.cpp" line="669"/>
         <location filename="../mountoperation.cpp" line="297"/>
-        <location filename="../utilities.cpp" line="150"/>
-        <location filename="../utilities.cpp" line="289"/>
+        <location filename="../utilities.cpp" line="154"/>
+        <location filename="../utilities.cpp" line="318"/>
         <source>Error</source>
         <translation>Помилка</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="226"/>
+        <location filename="../utilities.cpp" line="230"/>
         <source>Create Folder</source>
         <translation>Створити теку</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="227"/>
+        <location filename="../utilities.cpp" line="231"/>
         <source>Create File</source>
         <translation>Створити файл</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="231"/>
+        <location filename="../utilities.cpp" line="235"/>
         <source>Please enter a new file name:</source>
         <translation>Будь ласка, введіть назву нового файлу:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="232"/>
+        <location filename="../utilities.cpp" line="236"/>
         <source>New file</source>
         <translation>Новий файл</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="236"/>
+        <location filename="../utilities.cpp" line="240"/>
         <source>Please enter a new folder name:</source>
         <translation>Будь ласка, введіть нову назву теки:</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="237"/>
+        <location filename="../utilities.cpp" line="241"/>
         <source>New folder</source>
         <translation>Нова тека</translation>
     </message>
     <message>
-        <location filename="../utilities.cpp" line="242"/>
+        <location filename="../utilities.cpp" line="246"/>
         <source>Enter a name for the new %1:</source>
         <translation>Введіть назву для нової %1:</translation>
     </message>
